@@ -139,7 +139,10 @@ class AudienceQuery(object):
 
             if not isinstance(argument, list):
                 raise InvalidQuery(f'The `{operator}` operator expects a list')
-            return AudienceQuery(argument, op_c1=operator, allowed_fields=allowed_fields)
+
+            query = [cls.parse(q, allowed_fields=allowed_fields) for q in argument]
+
+            return AudienceQuery(query, op_c1=operator, allowed_fields=allowed_fields)
 
         elif operator in ('$not',):
 
@@ -149,7 +152,9 @@ class AudienceQuery(object):
         else:
             raise InvalidQuery(f'Unknown operator {operator}')
 
-        return AudienceQuery(argument, op_c1=operator, allowed_fields=allowed_fields)
+        query = cls.parse(argument)
+
+        return AudienceQuery(query, op_c1=operator, allowed_fields=allowed_fields)
 
     @classmethod
     def parse_query_atom(cls,
@@ -223,6 +228,9 @@ class AudienceQuery(object):
             elif isinstance(part, QueryAtom):
                 res.append(part.run(data.get(part.var)))
 
+            else:
+                raise InvalidQuery(f'Invalid query part of type {type(part)}')
+
         if not self.op_c1 is None and self.op_c1 == '$or':
             return any(res)
 
